<?php
/**
* Smarty Template
*
* Integration of Smarty with MediaWiki for easy templating
*
* @author Mick van der Most van Spijk
* @version 1.0.0
*/

// Smarty
@require_once "Smarty.class.php";

if (!class_exists('Smarty')) {
	wfReportException(new MWException('Smarty not found, is it installed and added to the PHP include_path?'));
	die;
}

/**
 * Generic wrapper for template functions, with interface
 * compatible with what we use of PHPTAL 0.7.
 * @addtogroup Skins
 */
class SmartyTemplate extends Smarty {
	/**
	 * @public
	 */
	public function __construct() {
		$this->data = array();
		$this->translator = new MediaWiki_I18N();

		// @todo should this be used? We already choose the skin to use
		global $wgUser;
		$this->skin = $wgUser->getSkin();
		
		global $IP;
		$this->template_dir = 'skins/';
		$this->compile_dir = $IP.'/tmp/templates_c/';
		$this->config_dir = $IP.'/tmp/configs/';
		$this->cache_dir = $IP.'/tmp/cache/';

		$this->caching = false;
		$this->debugging = false;
	
		// catch all global vars
		$this->globals =& $GLOBALS;

		//$this->assign('name', 'Mickos');
		$this->assign('this', &$this);
	}

	// smarty doesnt understand static
	public function makeGlobalVariablesScript($data) {
		return Skin::makeGlobalVariablesScript($data);
	}

	public function sanitizer_escapeId($key) {
		return Sanitizer::escapeId($key);
	}

	public function set( $name, $value ) {
		$this->data[$name] = $value;
	}

	public function setRef($name, &$value) {
		$this->data[$name] =& $value;
	}

	public function setTranslator( &$t ) {
		$this->translator = &$t;
	}

	public function execute() {
		// start smarty stuff
		$this->display(strtolower($this->skin->template).'/'.$this->skin->template.'.tpl');
	}


	/**
	 *
	 */
	public function text( $str ) { // cannot be private, must be called from the template
		echo htmlspecialchars( $this->data[$str] );
	}

	/**
	 *
	 */
	public function jstext( $str ) {
		echo Xml::escapeJsString( $this->data[$str] );
	}

	/**
	 * 
	 */
	public function html( $str ) {
		echo $this->data[$str];
	}

	/**
	 * 
	 */
	public function msg( $str ) {
		echo htmlspecialchars( $this->translator->translate( $str ) );
	}

	/**
	 * 
	 */
	public function msgHtml( $str ) {
		echo $this->translator->translate( $str );
	}

	/**
	 * An ugly, ugly hack.
	 * 
	 */
	public function msgWiki( $str ) {
		global $wgParser, $wgTitle, $wgOut;

		$text = $this->translator->translate( $str );
		$parserOutput = $wgParser->parse( 
			$text, 
			$wgTitle,
			$wgOut->parserOptions(), 
			true 
		);

		echo $parserOutput->getText();
	}

	/**
	 * 
	 */
	public function haveData( $str ) {
		return isset( $this->data[$str] );
	}

	/**
	 * 
	 */
	public function haveMsg( $str ) {
		$msg = $this->translator->translate( $str );
		return ($msg != '-') && ($msg != ''); # ????
	}

	/**
	 * Return an array of specialpages for the template
	 */
	public function getSpecialPages() {
		return array('contributions', 'log', 'blockip', 'emailuser', 'upload', 'specialpages');
	}

	public function getFooterLinks() {
		return array(
			'lastmod', 'viewcount', 'numberofwatchingusers', 'credits', 'copyright',
			'privacy', 'about', 'disclaimer', 'tagline',
		);
	}
}
?>